@@ -50,7 +50,7 @@ html_theme = 'alabaster'
 # so a file named "default.css" will overwrite the builtin "default.css".
 html_static_path = ['_static']
 autodoc_mock_imports = ['econsieve', 'particles', 'numpy', 'pandas', 'emcee', 'kombine', 'pathos',
-                        'yaml', 'sympy', 'scipy', 'numba', 'tqdm', 'dill', 'pygmo', 'matplotlib', 'interpolation', 'chaospy']
+                        'yaml', 'scipy', 'numba', 'tqdm', 'dill', 'pygmo', 'matplotlib', 'interpolation', 'chaospy']
 
 
 def setup(app):
